==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/ListDeviceRegistrationKeyPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.ListDeviceRegistrationKeyPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property deviceName The name of the device resource.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class ListDeviceRegistrationKeyPlainArgs(
    public val deviceName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.ListDeviceRegistrationKeyPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridnetwork.inputs.ListDeviceRegistrationKeyPlainArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.ListDeviceRegistrationKeyPlainArgs.builder()
            .deviceName(deviceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListDeviceRegistrationKeyPlainArgs].
 */
@PulumiTagMarker
public class ListDeviceRegistrationKeyPlainArgsBuilder internal constructor() {
    private var deviceName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the device resource.
     */
    @JvmName("keetucdjceoswbpj")
    public suspend fun deviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.deviceName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("rdgabnqqdtdgpjdc")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListDeviceRegistrationKeyPlainArgs = ListDeviceRegistrationKeyPlainArgs(
        deviceName = deviceName ?: throw PulumiNullFieldException("deviceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/ListDeviceRegistrationKeyPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.ListDeviceRegistrationKeyPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property deviceName The name of the device resource.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class ListDeviceRegistrationKeyPlainArgs(
    public val deviceName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.ListDeviceRegistrationKeyPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridnetwork.inputs.ListDeviceRegistrationKeyPlainArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.ListDeviceRegistrationKeyPlainArgs.builder()
            .deviceName(deviceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListDeviceRegistrationKeyPlainArgs].
 */
@PulumiTagMarker
public class ListDeviceRegistrationKeyPlainArgsBuilder internal constructor() {
    private var deviceName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the device resource.
     */
    @JvmName("fkvuaaxpaxcqdevy")
    public suspend fun deviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.deviceName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("rbidesudkwovvbyc")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListDeviceRegistrationKeyPlainArgs = ListDeviceRegistrationKeyPlainArgs(
        deviceName = deviceName ?: throw PulumiNullFieldException("deviceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
